package com.hzya.frame.grpU8.nxproof.pubbmxx.dao;



import com.hzya.frame.basedao.dao.IBaseDao;
import com.hzya.frame.grpU8.nxproof.pubbmxx.entity.SenderPubbmxxEntity;

import java.util.List;

/**
 * (pubbmxx: table)表数据库访问层
 *
 * @author makejava
 * @since 2024-06-20 09:48:44
 */
public interface ISenderPubbmxxDao extends IBaseDao<SenderPubbmxxEntity, String> {

    /**
     *
     * @content 查询部门信息  卫生院
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/20 10:11
     * **/
    List<SenderPubbmxxEntity> querySenderPubbmxxEntity(SenderPubbmxxEntity senderPubbmxxEntity);

    /**
     *
     * @content 保存部门信息到日志表中 卫生院
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/26 15:26
     * **/
    SenderPubbmxxEntity  saveSenderPubbmxxEntity(SenderPubbmxxEntity senderPubbmxxEntity);

    /**
     *
     * @content 更新部门信息到日志表中 卫生院
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/26 15:26
     * **/
    SenderPubbmxxEntity  updateSenderPubbmxxEntity(SenderPubbmxxEntity senderPubbmxxEntity);


    /**
     *
     * @content 查询部门信息 卫生局
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/20 10:11
     * **/
    List<SenderPubbmxxEntity> queryPubbmxxHealthBureau(SenderPubbmxxEntity senderPubbmxxEntity);

    /**
     *
     * @content 保存部门信息 卫生局
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/26 15:26
     * **/
    SenderPubbmxxEntity  savePubbmxxHealthBureau(SenderPubbmxxEntity senderPubbmxxEntity);

    /**
     *
     * @content 更新部门信息 卫生局
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/26 15:26
     * **/
    SenderPubbmxxEntity  updatePubbmxxHealthBureau(SenderPubbmxxEntity senderPubbmxxEntity );

    /**
     *
     * @content 删除部门信息
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/8/9 17:27
     * **/
    Integer deletePubbmxxHealthBureau(SenderPubbmxxEntity senderPubbmxxEntity );



}

